import names
import argparse


parser = argparse.ArgumentParser()
parser.add_argument("--gender", help="set male of female")
args = parser.parse_args()

name = names.get_full_name(gender=args.gender)

print(name, len(name) - 1)



# -*- coding: utf-8 -*-


from setuptools import find_packages, setup

setup(
    name='get_names_strzelczyk',
    version='1.0.1',
    author='SomeCompany PLC',
    author_email='dave@example.com',
    packages=find_packages(),
    url="https://github.com",
    scripts=['gen_names_strzelczyk/gen_names_strzelczyk.py', 'bin/gen_names_strzelczyk.bat'],
    include_package_data=True,
    description='Super useful library',
    install_requires=['names']
)